@@ -17,14 +17,12 @@ import Data.Char (toUpper)
 import Data.List
 import Data.Maybe
 import Data.Time.Calendar
-import Safe (headMay)
 import System.Console.Haskeline (InputT, runInputT, defaultSettings, setComplete, getInputLine)
 import System.Console.Haskeline.Completion
 import System.IO ( stderr, hPutStrLn, hPutStr )
 import System.IO.Error
 import Text.ParserCombinators.Parsec
 import Text.Printf
-import qualified Data.Foldable as Foldable (find)
 import qualified Data.Set as Set
 
 import Hledger
@@ -88,9 +86,9 @@ getTransaction j opts defaultDate = do
       date = fixSmartDate today $ fromparse $ (parse smartdate "" . lowercase) datestr
       accept x = x == "." || (not . null) x &&
         if no_new_accounts_ opts
-            then isJust $ Foldable.find (== x) ant
+            then x `elem` existingaccts
             else True
-        where (ant,_,_,_) = groupPostings $ journalPostings j
+      existingaccts = journalAccountNames j
       getpostingsandvalidate = do
         ps <- getPostings (PostingState j accept True bestmatchpostings) []
         let t = nulltransaction{tdate=date
@@ -118,7 +116,7 @@ getPostings st enteredps = do
                 | otherwise = Nothing
                 where Just ps = historicalps
       defaultaccount = maybe Nothing (Just . showacctname) bestmatch
-      ordot | null enteredps || length enteredrealps == 1 = ""
+      ordot | null enteredps || length enteredrealps == 1 = "" :: String
             | otherwise = ", or . to record"
   account <- runInteraction j $ askFor (printf "account %d%s" n ordot) defaultaccount (Just accept)
   if account=="."
@@ -149,22 +147,20 @@ getPostings st enteredps = do
                 -- I think 1 or 4, whichever would show the most decimal places
                 p = maxprecisionwithpoint
       amountstr <- runInteractionDefault $ askFor (printf "amount  %d" n) defaultamountstr validateamount
-      let a  = fromparse $ runParser (amount <|> return missingmixedamt) ctx     "" amountstr
-          a' = fromparse $ runParser (amount <|> return missingmixedamt) nullctx "" amountstr
-          defaultamtused = Just (showMixedAmount a) == defaultamountstr
-          commodityadded | c == cwithnodef = Nothing
-                         | otherwise       = c
-              where c          = maybemixedamountcommodity a
-                    cwithnodef = maybemixedamountcommodity a'
-                    maybemixedamountcommodity = maybe Nothing (Just . commodity) . headMay . amounts
-          p = nullposting{paccount=stripbrackets account,
-                          pamount=a,
-                          ptype=postingtype account}
-          st' = if defaultamtused then st
-                   else st{psHistory = historicalps',
-                           psSuggestHistoricalAmount = False}
-      when (isJust commodityadded) $
-           liftIO $ hPutStrLn stderr $ printf "using default commodity (%s)" (symbol $ fromJust commodityadded)
+      let a  = fromparse $ runParser (amountp <|> return missingamt) ctx     "" amountstr
+          a' = fromparse $ runParser (amountp <|> return missingamt) nullctx "" amountstr
+          wasdefaultamtused = Just (showAmount a) == defaultamountstr
+          defaultcommodityadded | acommodity a == acommodity a' = Nothing
+                                | otherwise                     = Just $ acommodity a
+          p = nullposting{paccount=stripbrackets account
+                         ,pamount=mixed a
+                         ,ptype=postingtype account
+                         }
+          st' = if wasdefaultamtused
+                 then st
+                 else st{psHistory=historicalps', psSuggestHistoricalAmount=False}
+      when (isJust defaultcommodityadded) $
+           liftIO $ hPutStrLn stderr $ printf "using default commodity (%s)" (fromJust defaultcommodityadded)
       getPostings st' (enteredps ++ [p])
     where
       j = psJournal st
@@ -180,7 +176,7 @@ getPostings st enteredps = do
       postingtype _ = RegularPosting
       stripbrackets = dropWhile (`elem` "([") . reverse . dropWhile (`elem` "])") . reverse
       validateamount = Just $ \s -> (null s && not (null enteredrealps))
-                                   || isRight (runParser (amount>>many spacenonewline>>eof) ctx "" s)
+                                   || isRight (runParser (amountp >> many spacenonewline >> eof) ctx "" s)
 
 -- | Prompt for and read a string value, optionally with a default value
 -- and a validator. A validator causes the prompt to repeat until the
