@@ -1,4 +1,4 @@
-{-# LANGUAGE ScopedTypeVariables #-}
+{-# LANGUAGE ScopedTypeVariables, CPP #-}
 {-|
 
 Utilities for top-level modules and ghci. See also Hledger.Read and
@@ -34,6 +34,10 @@ import System.Process (readProcessWithExitCode)
 import System.Time (ClockTime, getClockTime, diffClockTimes, TimeDiff(TimeDiff))
 import Test.HUnit
 import Text.Printf
+#if __GLASGOW_HASKELL__ >= 706
+import System.Time (ClockTime(TOD))
+import Data.Time.Clock.POSIX (utcTimeToPOSIXSeconds)
+#endif
 
 import Hledger.Cli.Options
 import Hledger.Data
@@ -98,8 +102,18 @@ journalSpecifiedFileIsNewer Journal{filereadtime=tread} f = do
 fileModificationTime :: FilePath -> IO ClockTime
 fileModificationTime f
     | null f = getClockTime
-    | otherwise = getModificationTime f `C.catch` \(_::C.IOException) -> getClockTime
-
+    | otherwise = (do
+-- getModificationTime returned a ClockTime till GHC 7.6 (directory 1.2), now it's UTCTime
+#if __GLASGOW_HASKELL__ < 706
+        clo <- getModificationTime f
+#else
+        utc <- getModificationTime f
+        let nom = utcTimeToPOSIXSeconds utc
+        let clo = TOD (read $ takeWhile (`elem` "0123456789") $ show nom) 0 -- XXX read
+#endif
+        return clo
+        )
+        `C.catch` \(_::C.IOException) -> getClockTime
 -- | Attempt to open a web browser on the given url, all platforms.
 openBrowserOn :: String -> IO ExitCode
 openBrowserOn u = trybrowsers browsers u
